﻿using DropDownSample.UI.Types;
using DropDownSample.ViewModels;
using Eto.Forms;
using System;

namespace DropDownSample.UI.Controls
{
    class DDElementCell : CustomCell
    {
        internal DDPanelViewModel ViewModel { get; private set; }
        public DDElementCell(DDPanelViewModel viewModel)
        {
            this.ViewModel = viewModel;
            this.CommitEdit += new EventHandler<CellEventArgs>(OnCommitEdit);
        }

        #region Events
        private void OnCommitEdit(object sender, CellEventArgs e)
        {
            if (e.Item is DDGridItem item &&
                item.Tag is string[] tags)
            {
                item.SetValue(e.Column, item.ElementProperty);
            }
        }
        #endregion

        protected override Control OnCreateCell(CellEventArgs args)
        {
            if (args.Item is DDGridItem item)
            {
                DropDown dropDown = new DropDown
                {
                    DataStore = this.ViewModel.Elements,
                    ItemTextBinding = Binding.Property((DDElement e) => e.Name)
                };
                dropDown.SelectedValueBinding.Bind(item, i => i.ElementProperty);
                return dropDown;
            }
            return base.OnCreateCell(args);
        }

        protected override void OnConfigureCell(CellEventArgs args, Control control)
        {
            if (args.Item is DDGridItem item &&
                control is DropDown dropDown &&
                item.GetValue(args.Column) is DDElement element)
            {
                dropDown.SelectedValue = element;
            }
            else
            {
                base.OnConfigureCell(args, control);
            }
        }
    }
}
