﻿using DropDownSample.UI.Controls;
using DropDownSample.UI.Types;
using DropDownSample.ViewModels;
using Eto.Drawing;
using Eto.Forms;
using Rhino.UI;
using System;

namespace DropDownSample.UI.Panels
{
    [System.Runtime.InteropServices.Guid("7271E6A3-6634-4E75-9A26-C8150FF1B4ED")]
    public partial class DDPanel : Panel, IPanel
    {
        public static Guid PanelId => typeof(DDPanel).GUID;
        internal DDPanelViewModel ViewModel { get; private set; }
        internal GridView DDGridView { get; private set; }
        /// <summary>
        /// 
        /// </summary>
        /// <param name="documentSerialNumber"></param>
        public DDPanel(uint documentSerialNumber)
        {
            this.ViewModel = new DDPanelViewModel();
            this.DataContext = this.ViewModel;

            StackLayout stackLayout = new StackLayout
            {
                HorizontalContentAlignment = HorizontalAlignment.Stretch,
                VerticalContentAlignment = VerticalAlignment.Stretch,
                BackgroundColor = Colors.Transparent,
                Orientation = Orientation.Vertical,
                Padding = new Padding(0),
            };

            this.DDGridView = new GridView
            {
                DataStore = this.ViewModel.Data
            };
            stackLayout.Items.Add(new StackLayoutItem(this.DDGridView, true));
            this.Content = stackLayout;

            DDInitData();
            DDGridViewInit();
        }

        public void PanelClosing(uint documentSerialNumber, bool onCloseDocument)
        {

        }

        public void PanelHidden(uint documentSerialNumber, ShowPanelReason reason)
        {

        }

        public void PanelShown(uint documentSerialNumber, ShowPanelReason reason)
        {

        }

        #region Methods

        private void DDInitData()
        {
            for (int i = 0; i < 10; i++)
            {
                this.ViewModel.Elements.Add(new Types.DDElement("E" + i.ToString()));
            }
        }

        /// <summary>
        /// 
        /// </summary>
        private void DDGridViewInit()
        {
            this.DDGridView.Columns.Add(new GridColumn
            {
                HeaderText = "Name",
                ID = "Name",
                DataCell = new DDTextCell(),
                Resizable = true,
                Width = 200,
                Sortable = true,
                MinWidth = 100,
                MaxWidth = 1000,
            });

            this.DDGridView.Columns.Add(new GridColumn
            {
                HeaderText = "Element",
                ID = "Element",
                DataCell = new DDElementCell(this.ViewModel),
                Resizable = true,
                Width = 200,
                Sortable = true,
                MinWidth = 100,
                MaxWidth = 1000,
            });

            this.ViewModel.Data = new FilterCollection<DDGridItem>();
            Random random = new Random();

            for (int i = 0; i < 10; i++)
            {
                int index = random.Next(0, this.ViewModel.Elements.Count - 1);
                DDGridItem item = new DDGridItem
                {
                    Values = new object[] { "Name" + i.ToString(), this.ViewModel.Elements[index] },
                    Tag = new string[] { "Name", "Element" },
                };

                this.ViewModel.Data.Add(item);
            }

            this.DDGridView.DataStore = this.ViewModel.Data;
        }

        #endregion
    }
}
